@@ -36,56 +36,30 @@ class CausalTree(_CausalTree):
             params["quartile"] = quartile
             params["old_trigger_code"] = old_trigger_code
             if not honest and split_size <= 0.0 and weight <= 0.0:
-                # self.tree = AdaptiveTriggerTree(min_size=min_size, max_depth=max_depth,
-                #                                 split_size=split_size, weight=weight, seed=seed,
-                #                                 quartile=quartile, old_trigger_code=old_trigger_code)
                 self.tree = AdaptiveTriggerTree(**params)
-            elif honest and split_size <= 0.0 and weight <= 0.0:
+            elif honest and (split_size <= 0.0 or weight <= 0.0):
                 self.tree = HonestTriggerTree(**params)
-            elif val_honest and weight > 0.0:
-                # self.tree = TriggerTreeHonestValidation(min_size=min_size, max_depth=max_depth,
-                #                                         split_size=split_size, weight=weight, seed=seed,
-                #                                         quartile=quartile, old_trigger_code=old_trigger_code)
+            elif val_honest and weight > 0.0 and split_size > 0.0:
                 self.tree = TriggerTreeHonestValidation(**params)
-            elif honest and weight > 0.0:
-                # self.tree = TriggerTreeHonest(min_size=min_size, max_depth=max_depth, split_size=split_size,
-                #                               weight=weight, seed=seed, quartile=quartile,
-                #                               old_trigger_code=old_trigger_code)
+            elif honest and weight > 0.0 and split_size > 0.0:
                 self.tree = TriggerTreeHonest(**params)
             elif weight > 0.0 and split_size > 0.0:
-                # self.tree = TriggerTreeBase(min_size=min_size, max_depth=max_depth, split_size=split_size,
-                #                             weight=weight, seed=seed, quartile=quartile,
-                #                             old_trigger_code=old_trigger_code)
                 self.tree = TriggerTreeBase(**params)
             else:
-                # self.tree = AdaptiveTriggerTree(min_size=min_size, max_depth=max_depth,
-                #                                 split_size=split_size, weight=weight, seed=seed,
-                #                                 quartile=quartile, old_trigger_code=old_trigger_code)
                 self.tree = AdaptiveTriggerTree(**params)
         else:
             params["feature_batch_size"] = feature_batch_size
             if not honest and split_size <= 0.0 and weight <= 0.0:
-                # self.tree = AdaptiveTree(min_size=min_size, max_depth=max_depth,
-                #                          split_size=split_size, weight=weight, seed=seed)
                 self.tree = AdaptiveTree(**params)
-            elif honest and split_size <= 0.0 and weight <= 0.0:
+            elif honest and (split_size <= 0.0 or weight <= 0.0):
                 self.tree = HonestTree(**params)
-            elif val_honest and weight > 0.0:
-                # self.tree = CausalTreeLearnHonestValidation(min_size=min_size, max_depth=max_depth,
-                #                                             split_size=split_size, weight=weight, seed=seed,
-                #                                             feature_batch_size=feature_batch_size)
+            elif val_honest and weight > 0.0 and split_size > 0.0:
                 self.tree = CausalTreeLearnHonestValidation(**params)
-            elif honest and weight > 0.0:
-                # self.tree = CausalTreeLearnHonest(min_size=min_size, max_depth=max_depth, split_size=split_size,
-                #                                   weight=weight, seed=seed, feature_batch_size=feature_batch_size)
+            elif honest and weight > 0.0 and split_size > 0.0:
                 self.tree = CausalTreeLearnHonest(**params)
             elif weight > 0.0 and split_size > 0.0:
-                # self.tree = CausalTreeLearnBase(min_size=min_size, max_depth=max_depth, split_size=split_size,
-                #                                 weight=weight, seed=seed, feature_batch_size=feature_batch_size)
                 self.tree = CausalTreeLearnBase(**params)
             else:
-                # self.tree = AdaptiveTree(min_size=min_size, max_depth=max_depth,
-                #                          split_size=split_size, weight=weight, seed=seed)
                 self.tree = AdaptiveTree(**params)
 
         self.column_num = 0
@@ -110,6 +84,7 @@ class CausalTree(_CausalTree):
 
     def prune(self, alpha=0.05):
         self.tree.prune(alpha=alpha)
+        self.tree_depth = self.tree.tree_depth
 
     def get_groups(self, x):
         return self.tree.get_groups(x)
